@@ -6,13 +6,15 @@
 
 
 import filecmp
+import logging
+import math
 import os
 import re
 import shutil
 
 from .arrow_ import Datetime
 from .strlib import strfind, natural_sort
-from .pathlib_ import Path
+from .pathlib_ import Path, get_xllog
 
 ____file = """
 路径、文件、目录相关操作功能
@@ -39,12 +41,10 @@ class Dir(Path):
     def __init__(self, path=None, *, root=None, files=None):
         """根目录、工作目录
 
-        # TODO 用枚举类做个temp、destop等“常用目录清单”？
-
         >> Dir()  # 以当前文件夹作为root
         >> Dir(r'C:/pycode/code4101py')  # 指定目录
         """
-        super(Dir, self).__init__(path, root=root)
+        super().__init__(path, root=root)
         self.files = files or []  # 初始默认没有选中任何文件（文件夹）
 
     @property
@@ -82,6 +82,44 @@ class Dir(Path):
                            min_ctime=min_ctime, max_ctime=max_ctime, min_mtime=min_mtime, max_mtime=max_mtime)
         return Dir(self._path, files=natural_sort(self.files + files))
 
+    def procfiles(self, func, ref_dir=None, pinterval=None):
+        """ 对选中的文件迭代处理
+
+        :param func: 对每个文件进行处理的自定义接口函数
+            参数 p: 输入参数 Path 对象
+            return: 可以没有返回值，当有返回值时，会作为信息，表示要输出查看
+                TODO 以后可以返回字典结构，用不同的key表示不同的功能，可以控制些高级功能
+        :param ref_dir: 是否有个相对的目录，对比同子结构下的文件情况
+            使用该参数时，func的接口会变成两个参数，会输入原p1、目标p2两个文件参数
+        :param pinterval: print interval，是否输出处理进度，输入一个正整数值，则每个间隔的倍数，会显示处理进度
+            当间隔为1时，会输出每个正在执行的具体文件名
+            TODO 增加了按照进度比例作为间距的参数，例如每1%显示一次
+        :return:
+
+        TODO 支持多线程？
+        TODO 增设可以bfs还是dfs的功能？
+        """
+        xllog = get_xllog()
+        n_files = len(self.files)
+        width = math.ceil(math.log10(n_files + 1))
+        if ref_dir is not None: ref_dir = Dir(ref_dir)
+        if pinterval: xllog.info(f"Dir('{self.fullpath}') 使用 {func} 处理 {n_files} 个文件(夹)")
+        for i, p in enumerate(self.filepaths):
+            if pinterval and (i or pinterval == 1) and i % pinterval == 0:
+                # 如果间隔是一个文件，则输出具体的每个文件路径
+                message = f' {self.files[i]}' if pinterval == 1 else ''
+                xllog.info(f'{i:{width}d}/{n_files}={i / n_files:6.2%}{message}')
+            try:
+                if ref_dir:
+                    res = func(p, ref_dir / self.files[i])
+                else:
+                    res = func(p)
+                # if res is not None: print(res)
+            except Exception as e:
+                # 子函数里如果报错，不一定有记录文件路径信息，所以这里补充一下
+                xllog.info(f'处理到该文件出现错误：{p}')
+                raise e
+
     def select_invert(self):
         """反选，在"全集"中，选中当前状态下没有被选中的那些文件"""
         raise NotImplementedError
@@ -459,12 +497,12 @@ def writefile(ob, path='', *, encoding='utf8', if_exists='backup', suffix=None,
 def merge_dir(src, dst, if_exists='ignore'):
     """ 将src目录下的数据拷贝到dst目录
     """
-    d1, d2 = Dir(src), Dir(dst)
+
+    def func(p1, p2):
+        p1.copy(p2, if_exists=if_exists)
 
     # 只拷文件和空目录，不然逻辑会乱
-    for f in d1.select('*', type_='dir', max_size=0).select('*', type_='file').files:
-        p1, p2 = Path(d1 / f), Path(d2 / f)
-        p1.copy(p2, if_exists=if_exists)
+    Dir(src).select('**/*', type_='dir', max_size=0).select('**/*', type_='file').procfiles(func, ref_dir=dst)
 
 
 def extract_files(src, dst, pattern, if_exists='replace'):
